@@ -2,7 +2,7 @@
 from django.conf import global_settings, settings
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.functional import lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 # Group to add plugin to placeholder "Content"
 PLUGINS_GROUP = _("Richie Plugins")
@@ -49,6 +49,17 @@ for site_language in LANGUAGES_DICT:
 # the first matching locale will be used if your LANGUAGES setting declares languages without
 # regions.
 RFC_5646_LOCALES = lazy(
-    lambda: getattr(settings, "RFC_5646_LOCALES", ["en-US", "es-ES", "fr-FR", "fr-CA"]),
+    lambda: getattr(
+        settings, "RFC_5646_LOCALES", ["en-US", "es-ES", "pt-PT", "fr-FR", "fr-CA"]
+    ),
     list,
 )()
+
+GLIMPSE_PAGINATION = {
+    "categories": 8,
+    "courses": 8,
+    "organizations": 8,
+    "blogposts": 6,
+    "persons": 4,
+    "programs": 4,
+}
