@@ -3,6 +3,9 @@ from django.conf import settings
 
 from .utils import pick_image
 
+DEFAULT_DEMO_SITE_DOMAIN = "localhost:8070"
+DEFAULT_LMS_ENDPOINT = "http://localhost:8073"
+
 NB_OBJECTS = {
     "courses": 75,
     "course_courseruns": 5,
@@ -12,19 +15,19 @@ NB_OBJECTS = {
     "course_subjects": 2,
     "person_organizations": 3,
     "person_subjects": 3,
-    "organizations": 15,
+    "organizations": 24,
     "licences": 5,
     "persons": 50,
-    "blogposts": 20,
+    "blogposts": 26,
     "blogpost_levels": 1,
     "blogpost_tags": 1,
     "programs": 6,
     "programs_courses": 4,
-    "home_blogposts": 4,
-    "home_courses": 8,
+    "home_blogposts": 5,
+    "home_courses": 7,
     "home_organizations": 4,
     "home_subjects": 6,
-    "home_persons": 3,
+    "home_persons": 4,
     "home_programs": 4,
 }
 NB_OBJECTS.update(getattr(settings, "RICHIE_DEMO_NB_OBJECTS", {}))
@@ -52,7 +55,7 @@ PAGES_INFO = {
         "template": "courses/cms/category_list.html",
     },
     "organizations": {
-        "title": {"en": "Organizations", "fr": "Etablissements"},
+        "title": {"en": "Organizations", "fr": "Établissements"},
         "in_navigation": True,
         "template": "courses/cms/organization_list.html",
     },
@@ -81,9 +84,15 @@ PAGES_INFO = {
                 "in_navigation": True,
                 "template": "richie/single_column.html",
             },
+            "login-error": {
+                "title": {"en": "Login error", "fr": "Erreur de connexion"},
+                "in_navigation": False,
+                "template": "richie/single_column.html",
+            },
         },
     },
 }
+PAGES_INFO.update(getattr(settings, "RICHIE_DEMO_PAGES_INFO", {}))
 
 
 LEVELS_INFO = {
@@ -123,7 +132,7 @@ TAGS_INFO = {
 TAGS_INFO.update(getattr(settings, "RICHIE_DEMO_TAGS_INFO", {}))
 
 SUBJECTS_INFO = {
-    "page_title": {"en": "Subject", "fr": "Subjet"},
+    "page_title": {"en": "Subject", "fr": "Sujet"},
     "children": [
         {
             "page_title": {"en": "Science", "fr": "Sciences"},
@@ -272,7 +281,7 @@ ICONS_INFO = {
             "fill_icon": pick_image("icons")("accessible.png"),
         },
         {
-            "page_title": {"en": "Closed caption", "fr": "Sous-titres malentendants"},
+            "page_title": {"en": "Closed caption", "fr": "Malentendants"},
             "color": "#a11000",
             "fill_icon": pick_image("icons")("cc.png"),
         },
@@ -294,10 +303,13 @@ ICONS_INFO.update(getattr(settings, "RICHIE_DEMO_ICONS_INFO", {}))
 HOMEPAGE_CONTENT = {
     "en": {
         "banner_title": "Welcome to Richie",
-        "banner_content": "It works! This is the default homepage for the Richie CMS.",
+        "banner_content": (
+            """<h1 class="hero-intro__title">Welcome <strong>to Richie</strong></h1>"""
+            """<p>It works! This is the default homepage for the Richie CMS.</p>"""
+        ),
         "banner_template": "richie/large_banner/hero-intro.html",
         "button_template_name": "button-caesura",
-        "section_template": "richie/section/section_cadenced.html",
+        "section_template": "richie/section/section.html",
         "blogposts_title": "Last news",
         "blogposts_button_title": "More news",
         "courses_title": "Popular courses",
@@ -313,10 +325,13 @@ HOMEPAGE_CONTENT = {
     },
     "fr": {
         "banner_title": "Bienvenue sur Richie",
-        "banner_content": "Ça marche ! Ceci est la page d'accueil par défaut du CMS Richie.",
+        "banner_content": (
+            """<h1 class="hero-intro__title">Bienvenue <strong>sur Richie</strong></h1>"""
+            """<p>Ça marche ! Ceci est la page d'accueil par défaut du CMS Richie.</p>"""
+        ),
         "banner_template": "richie/large_banner/hero-intro.html",
         "button_template_name": "button-caesura",
-        "section_template": "richie/section/section_cadenced.html",
+        "section_template": "richie/section/section.html",
         "blogposts_title": "Actualités récentes",
         "blogposts_button_title": "Plus d'actualités",
         "courses_title": "Cours à la une",
@@ -341,7 +356,7 @@ SINGLECOLUMN_CONTENT = {
         "button_template_name": "button-caesura",
         "section_sample_title": "A sample section",
         "section_sample_button_title": "More!",
-        "section_sample_template": "richie/section/section_cadenced.html",
+        "section_sample_template": "richie/section/section.html",
     },
     "fr": {
         "banner_title": "Exemple de template avec une colonne unique",
@@ -350,19 +365,16 @@ SINGLECOLUMN_CONTENT = {
         "button_template_name": "button-caesura",
         "section_sample_title": "Une section d'exemple",
         "section_sample_button_title": "Plus !",
-        "section_sample_template": "richie/section/section_cadenced.html",
+        "section_sample_template": "richie/section/section.html",
     },
 }
 SINGLECOLUMN_CONTENT.update(getattr(settings, "RICHIE_DEMO_SINGLECOLUMN_CONTENT", {}))
 
 FOOTER_CONTENT = {
     "en": [
-        {
-            "items": [
-                {"name": "About", "internal_link": "annex__about"},
-                {"name": "Sitemap", "internal_link": "annex__sitemap"},
-            ]
-        },
+        {"name": "About", "internal_link": "annex__about"},
+        {"name": "Sitemap", "internal_link": "annex__sitemap"},
+        {"name": "Style guide", "external_link": "/styleguide/"},
         {
             "title": "Richie community",
             "items": [
@@ -371,16 +383,21 @@ FOOTER_CONTENT = {
                     "name": "Github",
                     "external_link": "https://github.com/openfun/richie",
                 },
+                {
+                    "name": "Site factory",
+                    "external_link": "https://github.com/openfun/richie-site-factory",
+                },
+                {
+                    "name": "Example site",
+                    "external_link": "https://www.fun-campus.fr",
+                },
             ],
         },
     ],
     "fr": [
-        {
-            "items": [
-                {"name": "A propos", "internal_link": "annex__about"},
-                {"name": "Plan du site", "internal_link": "annex__sitemap"},
-            ]
-        },
+        {"name": "A propos", "internal_link": "annex__about"},
+        {"name": "Plan du site", "internal_link": "annex__sitemap"},
+        {"name": "Style guide", "external_link": "/styleguide/"},
         {
             "title": "Communauté Richie",
             "items": [
@@ -389,11 +406,25 @@ FOOTER_CONTENT = {
                     "name": "Github",
                     "external_link": "https://github.com/openfun/richie",
                 },
+                {
+                    "name": "Usine à sites",
+                    "external_link": "https://github.com/openfun/richie-site-factory",
+                },
+                {
+                    "name": "Site exemple",
+                    "external_link": "https://www.fun-campus.fr",
+                },
             ],
         },
     ],
 }
-FOOTER_CONTENT.update(getattr(settings, "FOOTER_CONTENT", {}))
+FOOTER_CONTENT.update(getattr(settings, "RICHIE_DEMO_FOOTER_CONTENT", {}))
+
+COURSE_CONTENT = {
+    "en": {"partners_title": "Partners", "sponsors_title": "Sponsors"},
+    "fr": {"partners_title": "Partenaires", "sponsors_title": "Sponsors"},
+}
+COURSE_CONTENT.update(getattr(settings, "RICHIE_DEMO_COURSE_CONTENT", {}))
 
 SITEMAP_PAGE_PARAMS = {
     "blogposts": {"max_depth": 1},
