@@ -257,7 +257,7 @@ def create_demo_site():
             page_parent=pages_created["courses"],
             fill_licences=course_licences,
             fill_team=random.sample(
-                eligible_persons,
+                list(eligible_persons),
                 min(
                     random.randint(1, defaults.NB_OBJECTS["course_persons"]),  # nosec
                     len(eligible_persons),
@@ -365,6 +365,7 @@ def create_demo_site():
         languages_subset = random.sample(
             ["de", "en", "es", "fr", "it", "nl"], random.randint(1, 4)  # nosec
         )
+        # only half the courses have an enrollment count defined
         for i in range(nb_course_runs):
             course_run = factories.CourseRunFactory(
                 __sequence=i,
@@ -373,6 +374,7 @@ def create_demo_site():
                 ),
                 direct_course=course,
                 resource_link=f"{lms_endpoint}/courses/course-v1:edX+DemoX+Demo_Course/info",
+                enrollment_count=random.randint(1, 10000),  # nosec
             )
             for language in course.extended_object.get_languages():
                 with translation.override(language):
