@@ -10,7 +10,9 @@ ES_CHUNK_SIZE = 500
 ES_PAGE_SIZE = 10
 
 # Use a lazy to enable easier testing by not defining the value at bootstrap time
-ES_INDICES_PREFIX = lazy(lambda: settings.RICHIE_ES_INDICES_PREFIX)()
+ES_INDICES_PREFIX = lazy(
+    lambda: getattr(settings, "RICHIE_ES_INDICES_PREFIX", "richie")
+)()
 
 # Define which analyzer should be used for each language
 QUERY_ANALYZERS = getattr(
@@ -116,6 +118,8 @@ FILTERS_CONFIGURATION = [
             "is_autocompletable": True,
             "is_searchable": True,
             "min_doc_count": 0,
+            # Note: this is a special name that connects the filter to Organization objects
+            # in Richie as well was the corresponding indexer and API endpoint.
             "name": "organizations",
             "position": 4,
             "reverse_id": "organizations",
@@ -128,9 +132,44 @@ FILTERS_CONFIGURATION = [
             "is_autocompletable": True,
             "is_searchable": True,
             "min_doc_count": 0,
+            # Note: this is a special name that connects the filter to Person objects
+            # in Richie as well was the corresponding indexer and API endpoint.
             "name": "persons",
             "position": 5,
             "reverse_id": "persons",
         },
     ),
+    (
+        "richie.apps.search.filter_definitions.IndexableFilterDefinition",
+        {
+            "human_name": _("Licences"),
+            "is_autocompletable": True,
+            "is_searchable": True,
+            "min_doc_count": 0,
+            "name": "licences",
+            "position": 6,
+        },
+    ),
+    (
+        "richie.apps.search.filter_definitions.StaticChoicesFilterDefinition",
+        {
+            "fragment_map": {
+                "self-paced": [{"bool": {"must_not": {"exists": {"field": "pace"}}}}],
+                "lt-1h": [{"range": {"pace": {"lt": 60}}}],
+                "1h-2h": [{"range": {"pace": {"gte": 60, "lte": 120}}}],
+                "gt-2h": [{"range": {"pace": {"gt": 120}}}],
+            },
+            "human_name": _("Weekly pace"),
+            "min_doc_count": 0,
+            "name": "pace",
+            "position": 7,
+            "sorting": "conf",
+            "values": {
+                "self-paced": _("Self-paced"),
+                "lt-1h": _("Less than one hour"),
+                "1h-2h": _("One to two hours"),
+                "gt-2h": _("More than two hours"),
+            },
+        },
+    ),
 ]
